@@ -13,10 +13,11 @@ from elasticsearch_dsl.query import Q
 from invenio_db import db
 from invenio_records_resources.services import RecordService
 from invenio_records_resources.services.records.schema import \
-    MarshmallowServiceSchema
+    ServiceSchemaWrapper
 from sqlalchemy.orm.exc import NoResultFound
 
 from .config import RecordDraftServiceConfig
+from .results import VersionsList
 
 
 class RecordDraftService(RecordService):
@@ -31,7 +32,7 @@ class RecordDraftService(RecordService):
     @property
     def schema_parent(self):
         """Schema for parent records."""
-        return MarshmallowServiceSchema(self, schema=self.config.schema_parent)
+        return ServiceSchemaWrapper(self, schema=self.config.schema_parent)
 
     # Draft attrs
     @property
@@ -40,7 +41,8 @@ class RecordDraftService(RecordService):
         return self.config.draft_cls
 
     # High-level API
-    # Inherits record search, search_versions, read, create, delete and update
+    # Inherits record search, read, create, delete and update
+
     def search_drafts(self, identity, params=None, links_config=None,
                       es_preference=None, **kwargs):
         """Search for drafts records matching the querystring."""
@@ -89,12 +91,13 @@ class RecordDraftService(RecordService):
         """Retrieve latest record."""
         # Resolve and require permission
         record = self.record_cls.pid.resolve(id_)
-        self.require_permission(identity, "read", record=record)
 
         # Retrieve latest if record is not
         if not record.versions.is_latest:
             record = self.record_cls.get_record(record.versions.latest_id)
 
+        self.require_permission(identity, "read", record=record)
+
         return self.result_item(
             self, identity, record, links_config=links_config)
 
@@ -110,10 +113,12 @@ class RecordDraftService(RecordService):
 
         # Load data with service schema
         data, errors = self.schema.load(
-            identity,
             data,
-            pid=draft.pid,
-            record=draft,
+            context=dict(
+                identity=identity,
+                pid=draft.pid,
+                record=draft,
+            ),
             # Saving a draft only saves valid metadata and reports
             # (doesn't raise) errors
             raise_errors=False
@@ -208,8 +213,8 @@ class RecordDraftService(RecordService):
         self._validate_draft(identity, draft)
 
         # Create the record from the draft
-        record = self.record_cls.publish(draft)
         latest_id = draft.versions.latest_id
+        record = self.record_cls.publish(draft)
 
         # Run components
         for component in self.components:
@@ -286,12 +291,25 @@ class RecordDraftService(RecordService):
             **kwargs
         ).execute()
 
-        return self.result_list(
+        # NOTE: This illustrates some of the entangled code parts:
+        #       the same schema_search_links is used for all
+        #       self.result_list in this service, but actually this class
+        #       needs different schema_search_links (or schema_item_links)
+        #       for published records/drafts/versions...
+        #       The solution, so far, has been to create a new service
+        #       with a different configuration, but that service inherits from
+        #       this service. So this class doesn't have a semantic core: can't
+        #       look at it and associate a single config to get an idea
+        #       of what it does. Different methods assume a different
+        #       config! So we have to resort to hacking in a different
+        #       result_list just for this case.
+        return VersionsList(
             self,
             identity,
             search_result,
             params,
-            links_config=links_config
+            links_config=links_config,
+            pid_value=id_
         )
 
     def delete_draft(self, id_, identity, revision_id=None):
@@ -373,10 +391,12 @@ class RecordDraftService(RecordService):
         )
         # Validate the data - will raise ValidationError if not valid.
         self.schema.load(
-            identity,
             data=draft_item.data,
-            pid=draft.pid,
-            record=draft,
+            context=dict(
+                identity=identity,
+                pid=draft.pid,
+                record=draft,
+            ),
             raise_errors=True  # this is the default, but might as well be
                                # explicit
         )
